@@ -23,6 +23,8 @@
 ** Author: Peter Eriksson <pen@signum.se>
 */
 
+#include "system.h"
+
 #include <stdio.h>
 #include <fcntl.h>
 #include <gdbm.h>
@@ -52,10 +54,9 @@ static void inject_file(GDBM_FILE dbp, FILE *fp, int iflag, char *argv0)
 {
     char buf[8192];
     char *cp;
-    char *key;
     
 
-    while (cp = fgets(buf, sizeof(buf)-1, fp))
+    while ((cp = fgets(buf, sizeof(buf)-1, fp)) != NULL)
     {
 	int len = strlen(cp);
 
@@ -78,10 +79,9 @@ static void inject_file(GDBM_FILE dbp, FILE *fp, int iflag, char *argv0)
 }
 
 
-main(int argc, char *argv[])
+int main(int argc, char *argv[])
 {
     GDBM_FILE dbp;
-    datum kdat, vdat;
     char *fname;
     int i;
     
