@@ -45,6 +45,10 @@ int main(int argc, char *argv[])
 	    break;
 	}
     
+    if (i+1 >= argc) {
+      fprintf( stderr, "Usage: %s [-v] GDBM-File key\n", argv[0]);
+      exit( 1);
+    }
     dbp = gdbm_open(argv[i], 128, O_RDONLY, 0, NULL);
     if (dbp == NULL)
     {
