@@ -252,8 +252,17 @@ static GDBM_FILE open_database(const char *domain,
     char buf[1025];
 
 
+    if (debug_flag)
+	fprintf(stderr, "\topen_database(\"%s\", \"%s\")\n",
+		domain, map);
+    
     if (map[0] == '.' || strchr(map, '/'))
+    {
+	if (debug_flag)
+	    fprintf(stderr, "\t\t->Returning 0\n");
+	
 	return 0;
+    }
 
     strcpy(buf, domain);
     strcat(buf, "/");
@@ -261,8 +270,10 @@ static GDBM_FILE open_database(const char *domain,
     
     dbp = gdbm_open(buf, 0, O_RDONLY, 0, NULL);
 
-    if (debug_flag > 1 && dbp == NULL)
+    if (debug_flag && dbp == NULL)
 	Gperror("gdbm_open()");
+    else if (debug_flag)
+	fprintf(stderr, "\t\t->Returning OK!\n");
     
     return dbp;
 }
@@ -286,11 +297,17 @@ int read_database(GDBM_FILE dbp,
     
     if (ikey == NULL || ikey->dptr == NULL)
     {
+	if (debug_flag)
+	    fprintf(stderr, "\tread_database(), gdbm_firstkey()\n");
+	
 	ckey = gdbm_firstkey(dbp);
 	first_flag = 1;
     }
     else
     {
+	if (debug_flag)
+	    fprintf(stderr, "\tread_database(), gdbm_nextkey()\n");
+	
 	if ((flags & F_NEXT))
 	    ckey = gdbm_nextkey(dbp, *ikey);
 	else
@@ -886,6 +903,9 @@ ypresp_all *ypproc_all_2_svc(ypreq_nokey *nokey,
 		xdr_ypall_cb.u.close  = ypall_close;
 		xdr_ypall_cb.data = (void *) dbp;
 
+		if (debug_flag)
+		    fprintf(stderr, "\t -> First value returned.\n");
+			
 		return &result;
 	    }
 
@@ -893,6 +913,9 @@ ypresp_all *ypproc_all_2_svc(ypreq_nokey *nokey,
 	}
     }
     
+    if (debug_flag)
+	fprintf(stderr, "\t -> Error should have been returned.\n");
+	    
     return &result;
 }
 
